//Google cardboard AR demo.

//Called when application is started.
function OnStart()
{   
	//Fix orientation to landscape since
	//most phones cameras work this way.   
	app.SetOrientation( "Landscape" );
	  
	//Stop screen turning off.
    app.PreventScreenLock( true );
    
	//Create horizontal layout that fills the screen.
	lay = app.CreateLayout( "Linear", "Horizontal,FillXY,VCenter" );
 
	//Create tiny camera view control.
	//(fast phones can use higher res "SVGA" or "XGA")
	cam = app.CreateCameraView( 0.001, 0.001, "VGA" );	
	cam.SetOnReady( cam_OnReady );
	lay.AddChild( cam );  
	
	//Add main layout to app.
	app.AddLayout( lay );
}

//Called when camera is ready.
function cam_OnReady()
{
    //Create 2 image controls with a fixed internal 
    //bitmap the same size as camera view.
    var w = cam.GetImageWidth();
	var h = cam.GetImageHeight();
	
	//Create left eye preview image and drawing image over the top.
	layLeft = app.CreateLayout( "Frame" );
	imgLeftPrev = app.CreateImage( null, 0.4, 0.7, "Fix", w, h );
	layLeft.AddChild( imgLeftPrev );   
	imgLeftDraw = app.CreateImage( null, 0.4, 0.7, "Fix", w, h );
	SetDrawOptions( imgLeftDraw );
	layLeft.AddChild( imgLeftDraw );
	lay.AddChild( layLeft );   
	
	//Create right eye preview image and drawing image over the top.
	layRight = app.CreateLayout( "Frame" );
	imgRightPrev = app.CreateImage( null, 0.4, 0.7, "Fix", w, h );
	layRight.AddChild( imgRightPrev );   
	imgRightDraw = app.CreateImage( null, 0.4, 0.7, "Fix", w, h );
	SetDrawOptions( imgRightDraw );
	layRight.AddChild( imgRightDraw );
	lay.AddChild( layRight );   

    //Configure camera.
    cam.SetFocusMode( "Video" );
    cam.SetParameter( "iso", 400 );
    
    //Set duplicate images and start preview.
    cam.SetDuplicateImage( imgLeftPrev, imgRightPrev );
    cam.StartPreview();
    
    //Create and start sensor object in orientation mode.
	orient = app.CreateSensor( "Orientation", "slow" );
	orient.SetOnChange( orient_OnChange );  
	orient.SetMinChange( 0.5 ); 
	orient.SetMaxRate( 100 );
	orient.Start();
}

//Set drawing options for the given image.
function SetDrawOptions( img )
{
    img.SetAutoUpdate( false );
    img.SetAlpha( 0.5 );
	img.SetPaintColor( "#ff0000"  );
	img.SetLineWidth( 1 );
	img.SetTextSize( 10 );
}

//Draw a messge on screen.
function DrawText( txt, left, top )
{
    imgLeftDraw.Clear();
    imgRightDraw.Clear();
    imgLeftDraw.DrawText( txt, left, top ); 
    imgRightDraw.DrawText( txt, left, top ); 
    imgLeftDraw.Update();
    imgRightDraw.Update();
}

//Called when Orientation sensor changes.
function orient_OnChange( azimuth, pitch, roll, time )
{
    //Adjust values because the phone is on it's side.
    azimuth = (azimuth + 90)%360; 

    //Draw text.
    var msg = "Orientation: " + azimuth.toFixed(0) + " Degrees North"
	DrawText( msg, 0.1, 0.1 );
}

